pub(crate) fn maybe_normalize_pixels(
command_value: &DOMString,
document: &Document,
) -> Option<DOMString>Expand description
Only in the case we have resolved to actual pixels, we need to do its conversion. In other cases, we already have the relevant font size or corresponding css value. This avoids expensive conversions of pixels to other values.